package com.ruoyi.szxc.service;

import com.ruoyi.szxc.domain.SzxcCsFw;

import java.util.List;

/**
 * 场所房屋关联Service接口
 *
 * @author hs
 * @date 2024-03-30
 */
public interface ISzxcCsFwService
{
    /**
     * 查询场所房屋关联
     *
     * @param id 场所房屋关联主键
     * @return 场所房屋关联
     */
    public SzxcCsFw selectSzxcCsFwById(Long id);

    /**
     * 查询场所房屋关联列表
     *
     * @param szxcCsFw 场所房屋关联
     * @return 场所房屋关联集合
     */
    public List<SzxcCsFw> selectSzxcCsFwList(SzxcCsFw szxcCsFw);

    /**
     * 新增场所房屋关联
     *
     * @param szxcCsFw 场所房屋关联
     * @return 结果
     */
    public int insertSzxcCsFw(SzxcCsFw szxcCsFw);

    /**
     * 修改场所房屋关联
     *
     * @param szxcCsFw 场所房屋关联
     * @return 结果
     */
    public int updateSzxcCsFw(SzxcCsFw szxcCsFw);

    /**
     * 批量删除场所房屋关联
     *
     * @param ids 需要删除的场所房屋关联主键集合
     * @return 结果
     */
    public int deleteSzxcCsFwByIds(Long[] ids);

    /**
     * 删除场所房屋关联信息
     *
     * @param id 场所房屋关联主键
     * @return 结果
     */
    public int deleteSzxcCsFwById(Long id);
}
